Startup_R32x - bug 172444
diff --git a/org.eclipse.jdt.core/buildnotes_jdt-core.html b/org.eclipse.jdt.core/buildnotes_jdt-core.html
index b91f247..4cb8513 100644
--- a/org.eclipse.jdt.core/buildnotes_jdt-core.html
+++ b/org.eclipse.jdt.core/buildnotes_jdt-core.html
@@ -45,15 +45,17 @@
 <br>Project org.eclipse.jdt.core v_688_Startup_R32x
 (<a href="http://dev.eclipse.org/viewcvs/index.cgi/org.eclipse.jdt.core/?only_with_tag=v_688_Startup_R32x">cvs</a>).
 <h2>What's new in this drop</h2>
-<a href="http://bugs.eclipse.org/bugs/show_bug.cgi?id=179699">179699</a>
+
+<h3>Problem Reports Fixed</h3>
+<a href="http://bugs.eclipse.org/bugs/show_bug.cgi?id=172444">172444</a>
+build workspace operation launched after each startup
+<br><a href="http://bugs.eclipse.org/bugs/show_bug.cgi?id=179699">179699</a>
 type.newTypeHierarchy doesn't cancel
 <br><a href="http://bugs.eclipse.org/bugs/show_bug.cgi?id=138309">138309</a>
 [index] Optimize index files path storage in DiskIndex and IndexManager
 <br><a href="http://bugs.eclipse.org/bugs/show_bug.cgi?id=171653">171653</a>
 [index] Java Tooling initialization performance issue after startup
 
-<h3>Problem Reports Fixed</h3>
-
 <a name="v_687_Startup_R32x"></a>
 <p><hr><h1>
 Eclipse Platform Build Notes<br>
diff --git a/org.eclipse.jdt.core/model/org/eclipse/jdt/core/JavaCore.java b/org.eclipse.jdt.core/model/org/eclipse/jdt/core/JavaCore.java
index 0f183c5..5859140 100644
--- a/org.eclipse.jdt.core/model/org/eclipse/jdt/core/JavaCore.java
+++ b/org.eclipse.jdt.core/model/org/eclipse/jdt/core/JavaCore.java
@@ -2851,9 +2851,13 @@
 	public static void initializeAfterLoad(IProgressMonitor monitor) throws CoreException {
 		try {
 			if (monitor != null) monitor.beginTask(Messages.javamodel_initialization, 100);
-			// dummy query for waiting until the indexes are ready and classpath containers/variables are initialized
+			
+			 // initialize all containers and variables
+			JavaModelManager.getJavaModelManager().deltaState.initializeRoots();
+			
+			// dummy query for waiting until the indexes are ready
 			SearchEngine engine = new SearchEngine();
-			IJavaSearchScope scope = SearchEngine.createWorkspaceScope(); // initialize all containers and variables
+			IJavaSearchScope scope = SearchEngine.createWorkspaceScope();
 			try {
 				engine.searchAllTypeNames(
 					null,